==> RefPlus_1.20.0.zip: RefPlus/doc/RefPlus.R <==
###################################################
### chunk number 1: 
###################################################
#line 101 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpkJ4eJB/R.INSTALL497d2a65/RefPlus/inst/doc/RefPlus.Rnw"
##Use Dilution in affydata package
library(RefPlus)
library(affydata)
data(Dilution)
sampleNames(Dilution)


###################################################
### chunk number 2: 
###################################################
#line 110 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpkJ4eJB/R.INSTALL497d2a65/RefPlus/inst/doc/RefPlus.Rnw"
##Calculate RMA intensities using the rma function.
Ex0<-exprs(rma(Dilution))


###################################################
### chunk number 3: 
###################################################
#line 117 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpkJ4eJB/R.INSTALL497d2a65/RefPlus/inst/doc/RefPlus.Rnw"
##Background correct, estimate the probe effects, and calculate the 
##RMA intensities using rma.para function.
Para<-rma.para(Dilution[,1:3],bg=TRUE,exp=TRUE)
Ex1 <- Para[[3]]


###################################################
### chunk number 4: 
###################################################
#line 128 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpkJ4eJB/R.INSTALL497d2a65/RefPlus/inst/doc/RefPlus.Rnw"
##Calculate the RMA+ intensity using rmaplus function. 
Ex2 <- rmaplus(Dilution, rmapara=Para, bg = TRUE)


###################################################
### chunk number 5: 
###################################################
#line 135 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpkJ4eJB/R.INSTALL497d2a65/RefPlus/inst/doc/RefPlus.Rnw"
par(mfrow=c(2,2))
plot(Ex0[,1],Ex2[,1],pch=".",main=sampleNames(Dilution)[1])
plot(Ex0[,2],Ex2[,2],pch=".",main=sampleNames(Dilution)[2])
plot(Ex0[,3],Ex2[,3],pch=".",main=sampleNames(Dilution)[3])
plot(Ex0[,4],Ex2[,4],pch=".",main=sampleNames(Dilution)[4])


###################################################
### chunk number 6: 
###################################################
#line 149 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpkJ4eJB/R.INSTALL497d2a65/RefPlus/inst/doc/RefPlus.Rnw"
Para2 <- rma.para(Dilution[,2:4],bg=TRUE,exp=TRUE)
Ex3 <- rmaplus(Dilution, rmapara=Para2, bg = TRUE)


###################################################
### chunk number 7: 
###################################################
#line 157 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpkJ4eJB/R.INSTALL497d2a65/RefPlus/inst/doc/RefPlus.Rnw"
Ex4 <- (Ex2+Ex3)/2


###################################################
### chunk number 8: 
###################################################
#line 163 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpkJ4eJB/R.INSTALL497d2a65/RefPlus/inst/doc/RefPlus.Rnw"
par(mfrow=c(2,2))
plot(Ex0[,1],Ex4[,1],pch=".",main=sampleNames(Dilution)[1])
plot(Ex0[,2],Ex4[,2],pch=".",main=sampleNames(Dilution)[2])
plot(Ex0[,3],Ex4[,3],pch=".",main=sampleNames(Dilution)[3])
plot(Ex0[,4],Ex4[,4],pch=".",main=sampleNames(Dilution)[4])


###################################################
### chunk number 9: 
###################################################
#line 177 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpkJ4eJB/R.INSTALL497d2a65/RefPlus/inst/doc/RefPlus.Rnw"
sqrt(mean((Ex0-Ex2)^2))
sqrt(mean((Ex0-Ex3)^2))


###################################################
### chunk number 10: 
###################################################
#line 182 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpkJ4eJB/R.INSTALL497d2a65/RefPlus/inst/doc/RefPlus.Rnw"
sqrt(mean((Ex0-Ex4)^2))

==> RefPlus_1.22.0.zip: RefPlus/doc/RefPlus.R <==
###################################################
### chunk number 1: 
###################################################
#line 101 "RefPlus.Rnw"
##Use Dilution in affydata package
library(RefPlus)
library(affydata)
data(Dilution)
sampleNames(Dilution)


###################################################
### chunk number 2: 
###################################################
#line 110 "RefPlus.Rnw"
##Calculate RMA intensities using the rma function.
Ex0<-exprs(rma(Dilution))


###################################################
### chunk number 3: 
###################################################
#line 117 "RefPlus.Rnw"
##Background correct, estimate the probe effects, and calculate the 
##RMA intensities using rma.para function.
Para<-rma.para(Dilution[,1:3],bg=TRUE,exp=TRUE)
Ex1 <- Para[[3]]


###################################################
### chunk number 4: 
###################################################
#line 128 "RefPlus.Rnw"
##Calculate the RMA+ intensity using rmaplus function. 
Ex2 <- rmaplus(Dilution, rmapara=Para, bg = TRUE)


###################################################
### chunk number 5: 
###################################################
#line 135 "RefPlus.Rnw"
par(mfrow=c(2,2))
plot(Ex0[,1],Ex2[,1],pch=".",main=sampleNames(Dilution)[1])
plot(Ex0[,2],Ex2[,2],pch=".",main=sampleNames(Dilution)[2])
plot(Ex0[,3],Ex2[,3],pch=".",main=sampleNames(Dilution)[3])
plot(Ex0[,4],Ex2[,4],pch=".",main=sampleNames(Dilution)[4])


###################################################
### chunk number 6: 
###################################################
#line 149 "RefPlus.Rnw"
Para2 <- rma.para(Dilution[,2:4],bg=TRUE,exp=TRUE)
Ex3 <- rmaplus(Dilution, rmapara=Para2, bg = TRUE)


###################################################
### chunk number 7: 
###################################################
#line 157 "RefPlus.Rnw"
Ex4 <- (Ex2+Ex3)/2


###################################################
### chunk number 8: 
###################################################
#line 163 "RefPlus.Rnw"
par(mfrow=c(2,2))
plot(Ex0[,1],Ex4[,1],pch=".",main=sampleNames(Dilution)[1])
plot(Ex0[,2],Ex4[,2],pch=".",main=sampleNames(Dilution)[2])
plot(Ex0[,3],Ex4[,3],pch=".",main=sampleNames(Dilution)[3])
plot(Ex0[,4],Ex4[,4],pch=".",main=sampleNames(Dilution)[4])


###################################################
### chunk number 9: 
###################################################
#line 177 "RefPlus.Rnw"
sqrt(mean((Ex0-Ex2)^2))
sqrt(mean((Ex0-Ex3)^2))


###################################################
### chunk number 10: 
###################################################
#line 182 "RefPlus.Rnw"
sqrt(mean((Ex0-Ex4)^2))
